@@ -11,7 +11,7 @@ require Exporter;
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
-$VERSION = '1.1';
+$VERSION = '1.2';
 
 
 # Preloaded methods go here.
@@ -287,44 +287,44 @@ sub new {
 # Sets {tail} to value of {reset_tail}; effect is that first call 
 # uses {tail} and subsequent calls use {reset_tail}.
 sub position {
-    my $object=shift;
-    $object->{"endpos"}=sysseek($object->{handle},0,SEEK_END);
-    unless ($object->{"tail"}) {
-	$object->{endpos}=$object->{curpos}=
-	    sysseek($object->{handle},0,SEEK_END);
-    } elsif ($object->{"tail"}<0) {
-	$object->{endpos}=sysseek($object->{handle},0,SEEK_END);
-	$object->{curpos}=sysseek($object->{handle},0,SEEK_SET);
-    } else {
-	my $crs=0;
-	my $maxlen=sysseek($object->{handle},0,SEEK_END);
-	while ($crs<$object->{"tail"}+1) {
-	    my $avlen=length($object->{"buffer"})/($crs+1);
-	    $avlen=80 unless $avlen;
-	    my $calclen=$avlen*$object->{"tail"};
-	    $calclen+=1024 if $calclen<=length($object->{"buffer"});
-	    $calclen=$maxlen if $calclen>$maxlen;
-	    $object->{curpos}=sysseek($object->{handle},-$calclen,SEEK_END);
-	    sysread($object->{handle},$object->{"buffer"},
-		    $calclen);
-            $object->{"buffer"} =~ s/\015\012/\n/g if $Is_Win32;
-	    $object->{curpos}=sysseek($object->{handle},0,SEEK_CUR);
-	    $crs=$object->{"buffer"}=~tr/\n//;
-	    last if ($calclen>=$maxlen);
-	}
-	$object->{curpos}=sysseek($object->{handle},0,SEEK_CUR);
-	$object->{endpos}=sysseek($object->{handle},0,SEEK_END);
-	if ($crs>$object->{"tail"}) {
-	    my $toskip=$crs-$object->{"tail"};
-	    my $pos;
-	    $pos=index($object->{"buffer"},"\n");
-	    while (--$toskip) {
-		$pos=index($object->{"buffer"},"\n",$pos+1);
-	    }
-	    $object->{"buffer"}=substr($object->{"buffer"},$pos+1);
-	}
+  my $object=shift;
+  $object->{"endpos"}=sysseek($object->{handle},0,SEEK_END);
+  unless ($object->{"tail"}) {
+    $object->{endpos}=$object->{curpos}=
+      sysseek($object->{handle},0,SEEK_END);
+  } elsif ($object->{"tail"}<0) {
+    $object->{endpos}=sysseek($object->{handle},0,SEEK_END);
+    $object->{curpos}=sysseek($object->{handle},0,SEEK_SET);
+  } else {
+    my $crs=0;
+    my $maxlen=sysseek($object->{handle},0,SEEK_END);
+    while ($crs<$object->{"tail"}+1) {
+      my $avlen=length($object->{"buffer"})/($crs+1);
+      $avlen=80 unless $avlen;
+      my $calclen=$avlen*$object->{"tail"};
+      $calclen=length($object->{tail})+1024 if $calclen<=length($object->{"tail"});
+      $calclen=$maxlen if $calclen>$maxlen;
+      $object->{curpos}=sysseek($object->{handle},-$calclen,SEEK_END);
+      sysread($object->{handle},$object->{"buffer"},
+              $calclen);
+      $object->{"buffer"} =~ s/\015\012/\n/g if $Is_Win32;
+      $object->{curpos}=sysseek($object->{handle},0,SEEK_CUR);
+      $crs=$object->{"buffer"}=~tr/\n//;
+      last if ($calclen>=$maxlen);
     }
-    $object->{"tail"}=$object->{"reset_tail"};
+    $object->{curpos}=sysseek($object->{handle},0,SEEK_CUR);
+    $object->{endpos}=sysseek($object->{handle},0,SEEK_END);
+    if ($crs>$object->{"tail"}) {
+      my $toskip=$crs-$object->{"tail"};
+      my $pos;
+      $pos=index($object->{"buffer"},"\n");
+      while (--$toskip) {
+        $pos=index($object->{"buffer"},"\n",$pos+1);
+      }
+      $object->{"buffer"}=substr($object->{"buffer"},$pos+1);
+    }
+  }
+  $object->{"tail"}=$object->{"reset_tail"};
 }
 
 # Tries to open or reopen the file; failure is an error unless 
